@@ -1,4 +1,3 @@
-
 package MooseX::Storage::Format::JSON;
 use Moose::Role;
 
@@ -7,7 +6,7 @@ no warnings 'once';
 use JSON::Any;
 use utf8 ();
 
-our $VERSION   = '0.32';
+our $VERSION   = '0.34';
 our $AUTHORITY = 'cpan:STEVAN';
 
 requires 'pack';
@@ -21,7 +20,7 @@ sub thaw {
 
 sub freeze {
     my ( $self, @args ) = @_;
-    my $json = JSON::Any->new->objToJson( $self->pack(@args) );
+    my $json = JSON::Any->new(canonical => 1)->objToJson( $self->pack(@args) );
     utf8::decode($json) if !utf8::is_utf8($json) and utf8::valid($json); # if it's valid utf8 mark it as such
     return $json;
 }
